<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Плагін %1 не сумісний із системою.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Увімкнено режим польоту</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Параметри режиму польоту</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Вимкнено режим польоту</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Параметри Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Параметри Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>З&apos;єднано %1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Встановлюємо з&apos;єднання…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Вимкнено</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Додати розкладку клавіатури</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Дата, час</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-годинний час</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-годинний час</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Параметри часу</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вівторок</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Середа</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четвер</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>П&apos;ятниця</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Субота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Неділя</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>Понеділок</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>вівторок</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>середа</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>четвер</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>п&apos;ятниця</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>субота</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>неділя</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation>%1рік%2місяць%3день</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Ви справді хочете спорожнити %1 записи?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Цю дію неможливо відновити</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Невідомий пристрій</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Невідомий том</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Відмонтувати все</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Запускач</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Вийти з безпечного режиму</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Док-станція — безпечний режим</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Док-станція перебуває у безпечному режимі — будь ласка, вийдіть з нього для належного показу</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Кілька дисплеїв</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Область додатків</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Виберіть, які піктограми буде показано на бічній панелі</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Ефективний режим</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Розташування</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Залишати прихованим</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Малий</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Великий</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Показувати панель</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>На екрані, де перебуває вказівник</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Лише на головному екрані</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Багатозадачний перегляд</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Розстикуватись</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Клавіатура</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Живлення</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметри живлення</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Батарея %1, %2 хв залишилося</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Батарея %1, %2 год %3 хв залишилося</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Зарядка %1, %2 хв до повної</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Зарядка %1, %2 год %3 хв до повної</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Ємність %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Заряджається %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Ємність %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Ємність %1, повністю заряджено</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Панель</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Показувати панель</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Область додатків</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Показати Стільницю</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Розстикуватись</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Живлення</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Змінити обліковий запис</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Параметри живлення</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Гучність</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Увімкнути звук</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Вимкнути звук</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Параметри звуку</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Гучність %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Немає пристроїв виведення</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Смітник</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Смітник - %1 файл</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Смітник - %1 файлів</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Перемістити в кошик для сміття</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Пусто</translation>
    </message>
</context>
</TS>